import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the CallFunction class and type
 */
export type CallFunctionIntersection = CallFunction & Specification.CallFunction;
/**
 * Represents a constructor for the intersection of the CallFunction class and type
 */
export interface CallFunctionConstructor {
    new (model?: Partial<Specification.CallFunction>): CallFunctionIntersection;
}
/**
 * Represents a CallFunction with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class CallFunction extends _TaskBase {
    /**
     * Instanciates a new instance of the CallFunction class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the CallFunction.
     */
    constructor(model?: Partial<Specification.CallFunction>);
    /**
     * Validates the current instance of the CallFunction.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the CallFunction.
     * Creates a copy of the CallFunction, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the CallFunction instance.
     */
    normalize(): CallFunction & Specification.CallFunction;
}
export declare const _CallFunction: CallFunctionConstructor;
//# sourceMappingURL=call-function.d.ts.map