import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the CallGRPC class and type
 */
export type CallGRPCIntersection = CallGRPC & Specification.CallGRPC;
/**
 * Represents a constructor for the intersection of the CallGRPC class and type
 */
export interface CallGRPCConstructor {
    new (model?: Partial<Specification.CallGRPC>): CallGRPCIntersection;
}
/**
 * Represents a CallGRPC with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class CallGRPC extends _TaskBase {
    /**
     * Instanciates a new instance of the CallGRPC class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the CallGRPC.
     */
    constructor(model?: Partial<Specification.CallGRPC>);
    /**
     * Validates the current instance of the CallGRPC.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the CallGRPC.
     * Creates a copy of the CallGRPC, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the CallGRPC instance.
     */
    normalize(): CallGRPC & Specification.CallGRPC;
}
export declare const _CallGRPC: CallGRPCConstructor;
//# sourceMappingURL=call-grpc.d.ts.map