import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the CallOpenAPI class and type
 */
export type CallOpenAPIIntersection = CallOpenAPI & Specification.CallOpenAPI;
/**
 * Represents a constructor for the intersection of the CallOpenAPI class and type
 */
export interface CallOpenAPIConstructor {
    new (model?: Partial<Specification.CallOpenAPI>): CallOpenAPIIntersection;
}
/**
 * Represents a CallOpenAPI with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class CallOpenAPI extends _TaskBase {
    /**
     * Instanciates a new instance of the CallOpenAPI class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the CallOpenAPI.
     */
    constructor(model?: Partial<Specification.CallOpenAPI>);
    /**
     * Validates the current instance of the CallOpenAPI.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the CallOpenAPI.
     * Creates a copy of the CallOpenAPI, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the CallOpenAPI instance.
     */
    normalize(): CallOpenAPI & Specification.CallOpenAPI;
}
export declare const _CallOpenAPI: CallOpenAPIConstructor;
//# sourceMappingURL=call-open-api.d.ts.map