import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the CallTask class and type
 */
export type CallTaskIntersection = CallTask & Specification.CallTask;
/**
 * Represents a constructor for the intersection of the CallTask class and type
 */
export interface CallTaskConstructor {
    new (model?: Partial<Specification.CallTask>): CallTaskIntersection;
}
/**
 * Represents a CallTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class CallTask extends ObjectHydrator<Specification.CallTask> {
    /**
     * Instanciates a new instance of the CallTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the CallTask.
     */
    constructor(model?: Partial<Specification.CallTask>);
    /**
     * Validates the current instance of the CallTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the CallTask.
     * Creates a copy of the CallTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the CallTask instance.
     */
    normalize(): CallTask & Specification.CallTask;
}
export declare const _CallTask: CallTaskConstructor;
//# sourceMappingURL=call-task.d.ts.map