import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Catalog class and type
 */
export type CatalogIntersection = Catalog & Specification.Catalog;
/**
 * Represents a constructor for the intersection of the Catalog class and type
 */
export interface CatalogConstructor {
    new (model?: Partial<Specification.Catalog>): CatalogIntersection;
}
/**
 * Represents a Catalog with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Catalog extends ObjectHydrator<Specification.Catalog> {
    /**
     * Instanciates a new instance of the Catalog class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Catalog.
     */
    constructor(model?: Partial<Specification.Catalog>);
    /**
     * Validates the current instance of the Catalog.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Catalog.
     * Creates a copy of the Catalog, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Catalog instance.
     */
    normalize(): Catalog & Specification.Catalog;
}
export declare const _Catalog: CatalogConstructor;
//# sourceMappingURL=catalog.d.ts.map