import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the CatchErrors class and type
 */
export type CatchErrorsIntersection = CatchErrors & Specification.CatchErrors;
/**
 * Represents a constructor for the intersection of the CatchErrors class and type
 */
export interface CatchErrorsConstructor {
    new (model?: Partial<Specification.CatchErrors>): CatchErrorsIntersection;
}
/**
 * Represents a CatchErrors with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class CatchErrors extends ObjectHydrator<Specification.CatchErrors> {
    /**
     * Instanciates a new instance of the CatchErrors class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the CatchErrors.
     */
    constructor(model?: Partial<Specification.CatchErrors>);
    /**
     * Validates the current instance of the CatchErrors.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the CatchErrors.
     * Creates a copy of the CatchErrors, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the CatchErrors instance.
     */
    normalize(): CatchErrors & Specification.CatchErrors;
}
export declare const _CatchErrors: CatchErrorsConstructor;
//# sourceMappingURL=catch-errors.d.ts.map