import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Container class and type
 */
export type ContainerIntersection = Container & Specification.Container;
/**
 * Represents a constructor for the intersection of the Container class and type
 */
export interface ContainerConstructor {
    new (model?: Partial<Specification.Container>): ContainerIntersection;
}
/**
 * Represents a Container with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Container extends ObjectHydrator<Specification.Container> {
    /**
     * Instanciates a new instance of the Container class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Container.
     */
    constructor(model?: Partial<Specification.Container>);
    /**
     * Validates the current instance of the Container.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Container.
     * Creates a copy of the Container, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Container instance.
     */
    normalize(): Container & Specification.Container;
}
export declare const _Container: ContainerConstructor;
//# sourceMappingURL=container.d.ts.map