import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the DoTask class and type
 */
export type DoTaskIntersection = DoTask & Specification.DoTask;
/**
 * Represents a constructor for the intersection of the DoTask class and type
 */
export interface DoTaskConstructor {
    new (model?: Partial<Specification.DoTask>): DoTaskIntersection;
}
/**
 * Represents a DoTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class DoTask extends _TaskBase {
    /**
     * Instanciates a new instance of the DoTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the DoTask.
     */
    constructor(model?: Partial<Specification.DoTask>);
    /**
     * Validates the current instance of the DoTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the DoTask.
     * Creates a copy of the DoTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the DoTask instance.
     */
    normalize(): DoTask & Specification.DoTask;
}
export declare const _DoTask: DoTaskConstructor;
//# sourceMappingURL=do-task.d.ts.map