import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Document class and type
 */
export type DocumentIntersection = Document & Specification.Document;
/**
 * Represents a constructor for the intersection of the Document class and type
 */
export interface DocumentConstructor {
    new (model?: Partial<Specification.Document>): DocumentIntersection;
}
/**
 * Represents a Document with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Document extends ObjectHydrator<Specification.Document> {
    /**
     * Instanciates a new instance of the Document class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Document.
     */
    constructor(model?: Partial<Specification.Document>);
    /**
     * Validates the current instance of the Document.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Document.
     * Creates a copy of the Document, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Document instance.
     */
    normalize(): Document & Specification.Document;
}
export declare const _Document: DocumentConstructor;
//# sourceMappingURL=document.d.ts.map