import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the EmitTask class and type
 */
export type EmitTaskIntersection = EmitTask & Specification.EmitTask;
/**
 * Represents a constructor for the intersection of the EmitTask class and type
 */
export interface EmitTaskConstructor {
    new (model?: Partial<Specification.EmitTask>): EmitTaskIntersection;
}
/**
 * Represents a EmitTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class EmitTask extends _TaskBase {
    /**
     * Instanciates a new instance of the EmitTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the EmitTask.
     */
    constructor(model?: Partial<Specification.EmitTask>);
    /**
     * Validates the current instance of the EmitTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the EmitTask.
     * Creates a copy of the EmitTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the EmitTask instance.
     */
    normalize(): EmitTask & Specification.EmitTask;
}
export declare const _EmitTask: EmitTaskConstructor;
//# sourceMappingURL=emit-task.d.ts.map