import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Endpoint class and type
 */
export type EndpointIntersection = Endpoint & Specification.Endpoint;
/**
 * Represents a constructor for the intersection of the Endpoint class and type
 */
export interface EndpointConstructor {
    new (model?: Partial<Specification.Endpoint>): EndpointIntersection;
}
/**
 * Represents a Endpoint with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Endpoint extends ObjectHydrator<Specification.Endpoint> {
    /**
     * Instanciates a new instance of the Endpoint class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Endpoint.
     */
    constructor(model?: Partial<Specification.Endpoint>);
    /**
     * Validates the current instance of the Endpoint.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Endpoint.
     * Creates a copy of the Endpoint, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Endpoint instance.
     */
    normalize(): Endpoint & Specification.Endpoint;
}
export declare const _Endpoint: EndpointConstructor;
//# sourceMappingURL=endpoint.d.ts.map