import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Export class and type
 */
export type ExportIntersection = Export & Specification.Export;
/**
 * Represents a constructor for the intersection of the Export class and type
 */
export interface ExportConstructor {
    new (model?: Partial<Specification.Export>): ExportIntersection;
}
/**
 * Represents a Export with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Export extends ObjectHydrator<Specification.Export> {
    /**
     * Instanciates a new instance of the Export class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Export.
     */
    constructor(model?: Partial<Specification.Export>);
    /**
     * Validates the current instance of the Export.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Export.
     * Creates a copy of the Export, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Export instance.
     */
    normalize(): Export & Specification.Export;
}
export declare const _Export: ExportConstructor;
//# sourceMappingURL=export.d.ts.map