import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ExtensionItem class and type
 */
export type ExtensionItemIntersection = ExtensionItem & Specification.ExtensionItem;
/**
 * Represents a constructor for the intersection of the ExtensionItem class and type
 */
export interface ExtensionItemConstructor {
    new (model?: Partial<Specification.ExtensionItem>): ExtensionItemIntersection;
}
/**
 * Represents a ExtensionItem with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ExtensionItem extends ObjectHydrator<Specification.ExtensionItem> {
    /**
     * Instanciates a new instance of the ExtensionItem class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ExtensionItem.
     */
    constructor(model?: Partial<Specification.ExtensionItem>);
    /**
     * Validates the current instance of the ExtensionItem.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ExtensionItem.
     * Creates a copy of the ExtensionItem, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ExtensionItem instance.
     */
    normalize(): ExtensionItem & Specification.ExtensionItem;
}
export declare const _ExtensionItem: ExtensionItemConstructor;
//# sourceMappingURL=extension-item.d.ts.map