import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Extension class and type
 */
export type ExtensionIntersection = Extension & Specification.Extension;
/**
 * Represents a constructor for the intersection of the Extension class and type
 */
export interface ExtensionConstructor {
    new (model?: Partial<Specification.Extension>): ExtensionIntersection;
}
/**
 * Represents a Extension with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Extension extends ObjectHydrator<Specification.Extension> {
    /**
     * Instanciates a new instance of the Extension class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Extension.
     */
    constructor(model?: Partial<Specification.Extension>);
    /**
     * Validates the current instance of the Extension.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Extension.
     * Creates a copy of the Extension, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Extension instance.
     */
    normalize(): Extension & Specification.Extension;
}
export declare const _Extension: ExtensionConstructor;
//# sourceMappingURL=extension.d.ts.map