import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ExternalResource class and type
 */
export type ExternalResourceIntersection = ExternalResource & Specification.ExternalResource;
/**
 * Represents a constructor for the intersection of the ExternalResource class and type
 */
export interface ExternalResourceConstructor {
    new (model?: Partial<Specification.ExternalResource>): ExternalResourceIntersection;
}
/**
 * Represents a ExternalResource with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ExternalResource extends ObjectHydrator<Specification.ExternalResource> {
    /**
     * Instanciates a new instance of the ExternalResource class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ExternalResource.
     */
    constructor(model?: Partial<Specification.ExternalResource>);
    /**
     * Validates the current instance of the ExternalResource.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ExternalResource.
     * Creates a copy of the ExternalResource, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ExternalResource instance.
     */
    normalize(): ExternalResource & Specification.ExternalResource;
}
export declare const _ExternalResource: ExternalResourceConstructor;
//# sourceMappingURL=external-resource.d.ts.map