import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ExternalScript class and type
 */
export type ExternalScriptIntersection = ExternalScript & Specification.ExternalScript;
/**
 * Represents a constructor for the intersection of the ExternalScript class and type
 */
export interface ExternalScriptConstructor {
    new (model?: Partial<Specification.ExternalScript>): ExternalScriptIntersection;
}
/**
 * Represents a ExternalScript with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ExternalScript extends ObjectHydrator<Specification.ExternalScript> {
    /**
     * Instanciates a new instance of the ExternalScript class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ExternalScript.
     */
    constructor(model?: Partial<Specification.ExternalScript>);
    /**
     * Validates the current instance of the ExternalScript.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ExternalScript.
     * Creates a copy of the ExternalScript, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ExternalScript instance.
     */
    normalize(): ExternalScript & Specification.ExternalScript;
}
export declare const _ExternalScript: ExternalScriptConstructor;
//# sourceMappingURL=external-script.d.ts.map