import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ForTask class and type
 */
export type ForTaskIntersection = ForTask & Specification.ForTask;
/**
 * Represents a constructor for the intersection of the ForTask class and type
 */
export interface ForTaskConstructor {
    new (model?: Partial<Specification.ForTask>): ForTaskIntersection;
}
/**
 * Represents a ForTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ForTask extends _TaskBase {
    /**
     * Instanciates a new instance of the ForTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ForTask.
     */
    constructor(model?: Partial<Specification.ForTask>);
    /**
     * Validates the current instance of the ForTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ForTask.
     * Creates a copy of the ForTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ForTask instance.
     */
    normalize(): ForTask & Specification.ForTask;
}
export declare const _ForTask: ForTaskConstructor;
//# sourceMappingURL=for-task.d.ts.map