import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ForkTask class and type
 */
export type ForkTaskIntersection = ForkTask & Specification.ForkTask;
/**
 * Represents a constructor for the intersection of the ForkTask class and type
 */
export interface ForkTaskConstructor {
    new (model?: Partial<Specification.ForkTask>): ForkTaskIntersection;
}
/**
 * Represents a ForkTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ForkTask extends _TaskBase {
    /**
     * Instanciates a new instance of the ForkTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ForkTask.
     */
    constructor(model?: Partial<Specification.ForkTask>);
    /**
     * Validates the current instance of the ForkTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ForkTask.
     * Creates a copy of the ForkTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ForkTask instance.
     */
    normalize(): ForkTask & Specification.ForkTask;
}
export declare const _ForkTask: ForkTaskConstructor;
//# sourceMappingURL=fork-task.d.ts.map