import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Input class and type
 */
export type InputIntersection = Input & Specification.Input;
/**
 * Represents a constructor for the intersection of the Input class and type
 */
export interface InputConstructor {
    new (model?: Partial<Specification.Input>): InputIntersection;
}
/**
 * Represents a Input with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Input extends ObjectHydrator<Specification.Input> {
    /**
     * Instanciates a new instance of the Input class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Input.
     */
    constructor(model?: Partial<Specification.Input>);
    /**
     * Validates the current instance of the Input.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Input.
     * Creates a copy of the Input, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Input instance.
     */
    normalize(): Input & Specification.Input;
}
export declare const _Input: InputConstructor;
//# sourceMappingURL=input.d.ts.map