import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the ListenTask class and type
 */
export type ListenTaskIntersection = ListenTask & Specification.ListenTask;
/**
 * Represents a constructor for the intersection of the ListenTask class and type
 */
export interface ListenTaskConstructor {
    new (model?: Partial<Specification.ListenTask>): ListenTaskIntersection;
}
/**
 * Represents a ListenTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class ListenTask extends _TaskBase {
    /**
     * Instanciates a new instance of the ListenTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the ListenTask.
     */
    constructor(model?: Partial<Specification.ListenTask>);
    /**
     * Validates the current instance of the ListenTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the ListenTask.
     * Creates a copy of the ListenTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the ListenTask instance.
     */
    normalize(): ListenTask & Specification.ListenTask;
}
export declare const _ListenTask: ListenTaskConstructor;
//# sourceMappingURL=listen-task.d.ts.map