import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Output class and type
 */
export type OutputIntersection = Output & Specification.Output;
/**
 * Represents a constructor for the intersection of the Output class and type
 */
export interface OutputConstructor {
    new (model?: Partial<Specification.Output>): OutputIntersection;
}
/**
 * Represents a Output with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Output extends ObjectHydrator<Specification.Output> {
    /**
     * Instanciates a new instance of the Output class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Output.
     */
    constructor(model?: Partial<Specification.Output>);
    /**
     * Validates the current instance of the Output.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Output.
     * Creates a copy of the Output, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Output instance.
     */
    normalize(): Output & Specification.Output;
}
export declare const _Output: OutputConstructor;
//# sourceMappingURL=output.d.ts.map