import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RaiseTask class and type
 */
export type RaiseTaskIntersection = RaiseTask & Specification.RaiseTask;
/**
 * Represents a constructor for the intersection of the RaiseTask class and type
 */
export interface RaiseTaskConstructor {
    new (model?: Partial<Specification.RaiseTask>): RaiseTaskIntersection;
}
/**
 * Represents a RaiseTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RaiseTask extends _TaskBase {
    /**
     * Instanciates a new instance of the RaiseTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RaiseTask.
     */
    constructor(model?: Partial<Specification.RaiseTask>);
    /**
     * Validates the current instance of the RaiseTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RaiseTask.
     * Creates a copy of the RaiseTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RaiseTask instance.
     */
    normalize(): RaiseTask & Specification.RaiseTask;
}
export declare const _RaiseTask: RaiseTaskConstructor;
//# sourceMappingURL=raise-task.d.ts.map