import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RunContainer class and type
 */
export type RunContainerIntersection = RunContainer & Specification.RunContainer;
/**
 * Represents a constructor for the intersection of the RunContainer class and type
 */
export interface RunContainerConstructor {
    new (model?: Partial<Specification.RunContainer>): RunContainerIntersection;
}
/**
 * Represents a RunContainer with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RunContainer extends ObjectHydrator<Specification.RunContainer> {
    /**
     * Instanciates a new instance of the RunContainer class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RunContainer.
     */
    constructor(model?: Partial<Specification.RunContainer>);
    /**
     * Validates the current instance of the RunContainer.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RunContainer.
     * Creates a copy of the RunContainer, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RunContainer instance.
     */
    normalize(): RunContainer & Specification.RunContainer;
}
export declare const _RunContainer: RunContainerConstructor;
//# sourceMappingURL=run-container.d.ts.map