import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RunScript class and type
 */
export type RunScriptIntersection = RunScript & Specification.RunScript;
/**
 * Represents a constructor for the intersection of the RunScript class and type
 */
export interface RunScriptConstructor {
    new (model?: Partial<Specification.RunScript>): RunScriptIntersection;
}
/**
 * Represents a RunScript with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RunScript extends ObjectHydrator<Specification.RunScript> {
    /**
     * Instanciates a new instance of the RunScript class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RunScript.
     */
    constructor(model?: Partial<Specification.RunScript>);
    /**
     * Validates the current instance of the RunScript.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RunScript.
     * Creates a copy of the RunScript, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RunScript instance.
     */
    normalize(): RunScript & Specification.RunScript;
}
export declare const _RunScript: RunScriptConstructor;
//# sourceMappingURL=run-script.d.ts.map