import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RunShell class and type
 */
export type RunShellIntersection = RunShell & Specification.RunShell;
/**
 * Represents a constructor for the intersection of the RunShell class and type
 */
export interface RunShellConstructor {
    new (model?: Partial<Specification.RunShell>): RunShellIntersection;
}
/**
 * Represents a RunShell with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RunShell extends ObjectHydrator<Specification.RunShell> {
    /**
     * Instanciates a new instance of the RunShell class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RunShell.
     */
    constructor(model?: Partial<Specification.RunShell>);
    /**
     * Validates the current instance of the RunShell.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RunShell.
     * Creates a copy of the RunShell, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RunShell instance.
     */
    normalize(): RunShell & Specification.RunShell;
}
export declare const _RunShell: RunShellConstructor;
//# sourceMappingURL=run-shell.d.ts.map