import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RunTask class and type
 */
export type RunTaskIntersection = RunTask & Specification.RunTask;
/**
 * Represents a constructor for the intersection of the RunTask class and type
 */
export interface RunTaskConstructor {
    new (model?: Partial<Specification.RunTask>): RunTaskIntersection;
}
/**
 * Represents a RunTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RunTask extends _TaskBase {
    /**
     * Instanciates a new instance of the RunTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RunTask.
     */
    constructor(model?: Partial<Specification.RunTask>);
    /**
     * Validates the current instance of the RunTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RunTask.
     * Creates a copy of the RunTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RunTask instance.
     */
    normalize(): RunTask & Specification.RunTask;
}
export declare const _RunTask: RunTaskConstructor;
//# sourceMappingURL=run-task.d.ts.map