import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the RunWorkflow class and type
 */
export type RunWorkflowIntersection = RunWorkflow & Specification.RunWorkflow;
/**
 * Represents a constructor for the intersection of the RunWorkflow class and type
 */
export interface RunWorkflowConstructor {
    new (model?: Partial<Specification.RunWorkflow>): RunWorkflowIntersection;
}
/**
 * Represents a RunWorkflow with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class RunWorkflow extends ObjectHydrator<Specification.RunWorkflow> {
    /**
     * Instanciates a new instance of the RunWorkflow class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the RunWorkflow.
     */
    constructor(model?: Partial<Specification.RunWorkflow>);
    /**
     * Validates the current instance of the RunWorkflow.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the RunWorkflow.
     * Creates a copy of the RunWorkflow, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the RunWorkflow instance.
     */
    normalize(): RunWorkflow & Specification.RunWorkflow;
}
export declare const _RunWorkflow: RunWorkflowConstructor;
//# sourceMappingURL=run-workflow.d.ts.map