import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Schedule class and type
 */
export type ScheduleIntersection = Schedule & Specification.Schedule;
/**
 * Represents a constructor for the intersection of the Schedule class and type
 */
export interface ScheduleConstructor {
    new (model?: Partial<Specification.Schedule>): ScheduleIntersection;
}
/**
 * Represents a Schedule with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Schedule extends ObjectHydrator<Specification.Schedule> {
    /**
     * Instanciates a new instance of the Schedule class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Schedule.
     */
    constructor(model?: Partial<Specification.Schedule>);
    /**
     * Validates the current instance of the Schedule.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Schedule.
     * Creates a copy of the Schedule, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Schedule instance.
     */
    normalize(): Schedule & Specification.Schedule;
}
export declare const _Schedule: ScheduleConstructor;
//# sourceMappingURL=schedule.d.ts.map