import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Schema class and type
 */
export type SchemaIntersection = Schema & Specification.Schema;
/**
 * Represents a constructor for the intersection of the Schema class and type
 */
export interface SchemaConstructor {
    new (model?: Partial<Specification.Schema>): SchemaIntersection;
}
/**
 * Represents a Schema with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Schema extends ObjectHydrator<Specification.Schema> {
    /**
     * Instanciates a new instance of the Schema class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Schema.
     */
    constructor(model?: Partial<Specification.Schema>);
    /**
     * Validates the current instance of the Schema.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Schema.
     * Creates a copy of the Schema, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Schema instance.
     */
    normalize(): Schema & Specification.Schema;
}
export declare const _Schema: SchemaConstructor;
//# sourceMappingURL=schema.d.ts.map