import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Script class and type
 */
export type ScriptIntersection = Script & Specification.Script;
/**
 * Represents a constructor for the intersection of the Script class and type
 */
export interface ScriptConstructor {
    new (model?: Partial<Specification.Script>): ScriptIntersection;
}
/**
 * Represents a Script with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Script extends ObjectHydrator<Specification.Script> {
    /**
     * Instanciates a new instance of the Script class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Script.
     */
    constructor(model?: Partial<Specification.Script>);
    /**
     * Validates the current instance of the Script.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Script.
     * Creates a copy of the Script, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Script instance.
     */
    normalize(): Script & Specification.Script;
}
export declare const _Script: ScriptConstructor;
//# sourceMappingURL=script.d.ts.map