import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the SetTask class and type
 */
export type SetTaskIntersection = SetTask & Specification.SetTask;
/**
 * Represents a constructor for the intersection of the SetTask class and type
 */
export interface SetTaskConstructor {
    new (model?: Partial<Specification.SetTask>): SetTaskIntersection;
}
/**
 * Represents a SetTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class SetTask extends _TaskBase {
    /**
     * Instanciates a new instance of the SetTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the SetTask.
     */
    constructor(model?: Partial<Specification.SetTask>);
    /**
     * Validates the current instance of the SetTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the SetTask.
     * Creates a copy of the SetTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the SetTask instance.
     */
    normalize(): SetTask & Specification.SetTask;
}
export declare const _SetTask: SetTaskConstructor;
//# sourceMappingURL=set-task.d.ts.map