import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Shell class and type
 */
export type ShellIntersection = Shell & Specification.Shell;
/**
 * Represents a constructor for the intersection of the Shell class and type
 */
export interface ShellConstructor {
    new (model?: Partial<Specification.Shell>): ShellIntersection;
}
/**
 * Represents a Shell with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Shell extends ObjectHydrator<Specification.Shell> {
    /**
     * Instanciates a new instance of the Shell class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Shell.
     */
    constructor(model?: Partial<Specification.Shell>);
    /**
     * Validates the current instance of the Shell.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Shell.
     * Creates a copy of the Shell, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Shell instance.
     */
    normalize(): Shell & Specification.Shell;
}
export declare const _Shell: ShellConstructor;
//# sourceMappingURL=shell.d.ts.map