import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the SwitchItem class and type
 */
export type SwitchItemIntersection = SwitchItem & Specification.SwitchItem;
/**
 * Represents a constructor for the intersection of the SwitchItem class and type
 */
export interface SwitchItemConstructor {
    new (model?: Partial<Specification.SwitchItem>): SwitchItemIntersection;
}
/**
 * Represents a SwitchItem with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class SwitchItem extends ObjectHydrator<Specification.SwitchItem> {
    /**
     * Instanciates a new instance of the SwitchItem class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the SwitchItem.
     */
    constructor(model?: Partial<Specification.SwitchItem>);
    /**
     * Validates the current instance of the SwitchItem.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the SwitchItem.
     * Creates a copy of the SwitchItem, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the SwitchItem instance.
     */
    normalize(): SwitchItem & Specification.SwitchItem;
}
export declare const _SwitchItem: SwitchItemConstructor;
//# sourceMappingURL=switch-item.d.ts.map