import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the SwitchTask class and type
 */
export type SwitchTaskIntersection = SwitchTask & Specification.SwitchTask;
/**
 * Represents a constructor for the intersection of the SwitchTask class and type
 */
export interface SwitchTaskConstructor {
    new (model?: Partial<Specification.SwitchTask>): SwitchTaskIntersection;
}
/**
 * Represents a SwitchTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class SwitchTask extends _TaskBase {
    /**
     * Instanciates a new instance of the SwitchTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the SwitchTask.
     */
    constructor(model?: Partial<Specification.SwitchTask>);
    /**
     * Validates the current instance of the SwitchTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the SwitchTask.
     * Creates a copy of the SwitchTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the SwitchTask instance.
     */
    normalize(): SwitchTask & Specification.SwitchTask;
}
export declare const _SwitchTask: SwitchTaskConstructor;
//# sourceMappingURL=switch-task.d.ts.map