import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the TaskBase class and type
 */
export type TaskBaseIntersection = TaskBase & Specification.TaskBase;
/**
 * Represents a constructor for the intersection of the TaskBase class and type
 */
export interface TaskBaseConstructor {
    new (model?: Partial<Specification.TaskBase>): TaskBaseIntersection;
}
/**
 * Represents a TaskBase with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class TaskBase extends ObjectHydrator<Specification.TaskBase> {
    /**
     * Instanciates a new instance of the TaskBase class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the TaskBase.
     */
    constructor(model?: Partial<Specification.TaskBase>);
    /**
     * Validates the current instance of the TaskBase.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the TaskBase.
     * Creates a copy of the TaskBase, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the TaskBase instance.
     */
    normalize(): TaskBase & Specification.TaskBase;
}
export declare const _TaskBase: TaskBaseConstructor;
//# sourceMappingURL=task-base.d.ts.map