import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the TaskItem class and type
 */
export type TaskItemIntersection = TaskItem & Specification.TaskItem;
/**
 * Represents a constructor for the intersection of the TaskItem class and type
 */
export interface TaskItemConstructor {
    new (model?: Partial<Specification.TaskItem>): TaskItemIntersection;
}
/**
 * Represents a TaskItem with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class TaskItem extends ObjectHydrator<Specification.TaskItem> {
    /**
     * Instanciates a new instance of the TaskItem class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the TaskItem.
     */
    constructor(model?: Partial<Specification.TaskItem>);
    /**
     * Validates the current instance of the TaskItem.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the TaskItem.
     * Creates a copy of the TaskItem, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the TaskItem instance.
     */
    normalize(): TaskItem & Specification.TaskItem;
}
export declare const _TaskItem: TaskItemConstructor;
//# sourceMappingURL=task-item.d.ts.map