import { Specification } from '../definitions';
import { ArrayHydrator } from '../../hydrator';
/**
 * Represents the intersection between the TaskList class and type
 */
export type TaskListIntersection = TaskList & Specification.TaskList;
/**
 * Represents a constructor for the intersection of the TaskList class and type
 */
export interface TaskListConstructor {
    new (model?: Array<Specification.TaskItem> | number): TaskListIntersection;
}
/**
 * Represents a collection of Specification.TaskItem.
 * Inherits from ArrayHydrator to handle array-specific hydration.
 */
export declare class TaskList extends ArrayHydrator<Specification.TaskItem> {
    /**
     * Constructs a new instance of the TaskList class.
     *
     * @param model - Optional parameter which can be an array of objects or a number representing the array length.
     */
    constructor(model?: Array<Specification.TaskItem> | number);
    /**
     * Validates the current instance of the TaskList.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the TaskList.
     * Creates a copy of the TaskList, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the TaskList instance.
     */
    normalize(): TaskList;
}
export declare const _TaskList: TaskListConstructor;
//# sourceMappingURL=task-list.d.ts.map