import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Task class and type
 */
export type TaskIntersection = Task & Specification.Task;
/**
 * Represents a constructor for the intersection of the Task class and type
 */
export interface TaskConstructor {
    new (model?: Partial<Specification.Task>): TaskIntersection;
}
/**
 * Represents a Task with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Task extends ObjectHydrator<Specification.Task> {
    /**
     * Instanciates a new instance of the Task class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Task.
     */
    constructor(model?: Partial<Specification.Task>);
    /**
     * Validates the current instance of the Task.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Task.
     * Creates a copy of the Task, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Task instance.
     */
    normalize(): Task & Specification.Task;
}
export declare const _Task: TaskConstructor;
//# sourceMappingURL=task.d.ts.map