import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the TryTask class and type
 */
export type TryTaskIntersection = TryTask & Specification.TryTask;
/**
 * Represents a constructor for the intersection of the TryTask class and type
 */
export interface TryTaskConstructor {
    new (model?: Partial<Specification.TryTask>): TryTaskIntersection;
}
/**
 * Represents a TryTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class TryTask extends _TaskBase {
    /**
     * Instanciates a new instance of the TryTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the TryTask.
     */
    constructor(model?: Partial<Specification.TryTask>);
    /**
     * Validates the current instance of the TryTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the TryTask.
     * Creates a copy of the TryTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the TryTask instance.
     */
    normalize(): TryTask & Specification.TryTask;
}
export declare const _TryTask: TryTaskConstructor;
//# sourceMappingURL=try-task.d.ts.map