import { ObjectHydrator } from '../../hydrator';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the Use class and type
 */
export type UseIntersection = Use & Specification.Use;
/**
 * Represents a constructor for the intersection of the Use class and type
 */
export interface UseConstructor {
    new (model?: Partial<Specification.Use>): UseIntersection;
}
/**
 * Represents a Use with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class Use extends ObjectHydrator<Specification.Use> {
    /**
     * Instanciates a new instance of the Use class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the Use.
     */
    constructor(model?: Partial<Specification.Use>);
    /**
     * Validates the current instance of the Use.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the Use.
     * Creates a copy of the Use, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the Use instance.
     */
    normalize(): Use & Specification.Use;
}
export declare const _Use: UseConstructor;
//# sourceMappingURL=use.d.ts.map