import { _TaskBase } from './task-base';
import { Specification } from '../definitions';
/**
 * Represents the intersection between the WaitTask class and type
 */
export type WaitTaskIntersection = WaitTask & Specification.WaitTask;
/**
 * Represents a constructor for the intersection of the WaitTask class and type
 */
export interface WaitTaskConstructor {
    new (model?: Partial<Specification.WaitTask>): WaitTaskIntersection;
}
/**
 * Represents a WaitTask with methods for validation and normalization.
 * Inherits from ObjectHydrator which provides functionality for hydrating the state based on a model.
 */
export declare class WaitTask extends _TaskBase {
    /**
     * Instanciates a new instance of the WaitTask class.
     * Initializes properties based on the provided model if it is an object.
     *
     * @param model - Optional partial model object to initialize the WaitTask.
     */
    constructor(model?: Partial<Specification.WaitTask>);
    /**
     * Validates the current instance of the WaitTask.
     * Throws if invalid.
     */
    validate(workflow?: Partial<Specification.Workflow>): void;
    /**
     * Normalizes the current instance of the WaitTask.
     * Creates a copy of the WaitTask, invokes normalization hooks if available, and returns the normalized copy.
     *
     * @returns A normalized version of the WaitTask instance.
     */
    normalize(): WaitTask & Specification.WaitTask;
}
export declare const _WaitTask: WaitTaskConstructor;
//# sourceMappingURL=wait-task.d.ts.map