import { Specification } from './generated/definitions';
/**
 * Represents the possible lifecycle hooks of an instance
 */
export type LifecycleHooks<T> = {
    /**
     * The hook called at the end of the constructor
     * @param instance The instance being initialized
     */
    constructor?: (instance: T) => void;
    /**
     * The hook called before the validation
     * @param instance A copy instance being validated
     * @param workflow A workflow instance, used for DSL level validation
     */
    preValidation?: (instance: T, workflow?: Partial<Specification.Workflow>) => void;
    /**
     * The hook called after the validation
     * @param instance A copy instance being validated
     * @param workflow A workflow instance, used for DSL level validation
     */
    postValidation?: (instance: T, workflow?: Partial<Specification.Workflow>) => void;
    /**
     * The hook called to normalized the instance
     * @param instance A copy of the instance to normalize
     * @returns The normalized instance
     */
    normalize?: (instance: T) => T;
};
/**
 * The function used to register hooks
 * @param typeName The name of the type to register the hooks for
 * @param hooks The hooks to register
 */
export declare const registerHooks: (typeName: string, hooks: LifecycleHooks<any>) => void;
/**
 * Gets the lifecylce hook for the provided type, if any
 * @param typeName The type to get the lifecycle hook for
 * @returns The lifecycle hook, if any
 */
export declare const getLifecycleHooks: (typeName: string) => LifecycleHooks<any> | undefined;
//# sourceMappingURL=lifecycle-hooks.d.ts.map